==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/physicalinventoryline_001/PhysicalInventoryLine.java <==

package net.datastream.schemas.mp_entities.physicalinventoryline_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONLINEID;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EXPECTEDQUANTITY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PHYSICALQUANTITY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ISSUEDTO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}RETURNFROM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ATTACHTOEQUIPMENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVENTORYNOTES" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOBIN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}INVENTORYACTION" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionlineid",
    "partid",
    "bin",
    "lot",
    "expectedquantity",
    "physicalquantity",
    "manufacturerid",
    "manufacturerpartcode",
    "storeid",
    "issuedto",
    "returnfrom",
    "attachtoequipment",
    "assetid",
    "equipmentstatus",
    "inventorynotes",
    "tobin",
    "inventoryaction"
})
@XmlRootElement(name = "PhysicalInventoryLine")
public class PhysicalInventoryLine {

    @XmlElement(name = "TRANSACTIONLINEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONLINEID transactionlineid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "EXPECTEDQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expectedquantity;
    @XmlElement(name = "PHYSICALQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY physicalquantity;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "ISSUEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type issuedto;
    @XmlElement(name = "RETURNFROM", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type returnfrom;
    @XmlElement(name = "ATTACHTOEQUIPMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type attachtoequipment;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "INVENTORYNOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inventorynotes;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type tobin;
    @XmlElement(name = "INVENTORYACTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type inventoryaction;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the transactionlineid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public TRANSACTIONLINEID getTRANSACTIONLINEID() {
        return transactionlineid;
    }

    /**
     * Sets the value of the transactionlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public void setTRANSACTIONLINEID(TRANSACTIONLINEID value) {
        this.transactionlineid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Sets the value of the lot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Gets the value of the expectedquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPECTEDQUANTITY() {
        return expectedquantity;
    }

    /**
     * Sets the value of the expectedquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPECTEDQUANTITY(QUANTITY value) {
        this.expectedquantity = value;
    }

    /**
     * Gets the value of the physicalquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHYSICALQUANTITY() {
        return physicalquantity;
    }

    /**
     * Sets the value of the physicalquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHYSICALQUANTITY(QUANTITY value) {
        this.physicalquantity = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the manufacturerpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Sets the value of the manufacturerpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the issuedto property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getISSUEDTO() {
        return issuedto;
    }

    /**
     * Sets the value of the issuedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setISSUEDTO(EQUIPMENTID_Type value) {
        this.issuedto = value;
    }

    /**
     * Gets the value of the returnfrom property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getRETURNFROM() {
        return returnfrom;
    }

    /**
     * Sets the value of the returnfrom property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setRETURNFROM(EQUIPMENTID_Type value) {
        this.returnfrom = value;
    }

    /**
     * Gets the value of the attachtoequipment property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getATTACHTOEQUIPMENT() {
        return attachtoequipment;
    }

    /**
     * Sets the value of the attachtoequipment property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setATTACHTOEQUIPMENT(EQUIPMENTID_Type value) {
        this.attachtoequipment = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the inventorynotes property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINVENTORYNOTES() {
        return inventorynotes;
    }

    /**
     * Sets the value of the inventorynotes property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINVENTORYNOTES(String value) {
        this.inventorynotes = value;
    }

    /**
     * Gets the value of the tobin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Sets the value of the tobin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Gets the value of the inventoryaction property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINVENTORYACTION() {
        return inventoryaction;
    }

    /**
     * Sets the value of the inventoryaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINVENTORYACTION(USERDEFINEDCODEID_Type value) {
        this.inventoryaction = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/physicalinventoryline_001/PhysicalInventoryLine.java <==

package net.datastream.schemas.mp_entities.physicalinventoryline_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.TRANSACTIONLINEID;
import net.datastream.schemas.mp_fields.USERDEFINEDCODEID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EXPECTEDQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PHYSICALQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISSUEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RETURNFROM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ATTACHTOEQUIPMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVENTORYNOTES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBIN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INVENTORYACTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionlineid",
    "partid",
    "bin",
    "lot",
    "expectedquantity",
    "physicalquantity",
    "manufacturerid",
    "manufacturerpartcode",
    "storeid",
    "issuedto",
    "returnfrom",
    "attachtoequipment",
    "assetid",
    "equipmentstatus",
    "inventorynotes",
    "tobin",
    "inventoryaction"
})
@XmlRootElement(name = "PhysicalInventoryLine")
public class PhysicalInventoryLine {

    @XmlElement(name = "TRANSACTIONLINEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected TRANSACTIONLINEID transactionlineid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTID_Type partid;
    @XmlElement(name = "BIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected String bin;
    @XmlElement(name = "LOT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String lot;
    @XmlElement(name = "EXPECTEDQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY expectedquantity;
    @XmlElement(name = "PHYSICALQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY physicalquantity;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "ISSUEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type issuedto;
    @XmlElement(name = "RETURNFROM", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type returnfrom;
    @XmlElement(name = "ATTACHTOEQUIPMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type attachtoequipment;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "INVENTORYNOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inventorynotes;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields")
    protected BINID_Type tobin;
    @XmlElement(name = "INVENTORYACTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDCODEID_Type inventoryaction;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the transactionlineid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public TRANSACTIONLINEID getTRANSACTIONLINEID() {
        return transactionlineid;
    }

    /**
     * Sets the value of the transactionlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONLINEID }
     *     
     */
    public void setTRANSACTIONLINEID(TRANSACTIONLINEID value) {
        this.transactionlineid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the bin property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBIN() {
        return bin;
    }

    /**
     * Sets the value of the bin property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBIN(String value) {
        this.bin = value;
    }

    /**
     * Gets the value of the lot property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOT() {
        return lot;
    }

    /**
     * Sets the value of the lot property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOT(String value) {
        this.lot = value;
    }

    /**
     * Gets the value of the expectedquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getEXPECTEDQUANTITY() {
        return expectedquantity;
    }

    /**
     * Sets the value of the expectedquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setEXPECTEDQUANTITY(QUANTITY value) {
        this.expectedquantity = value;
    }

    /**
     * Gets the value of the physicalquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getPHYSICALQUANTITY() {
        return physicalquantity;
    }

    /**
     * Sets the value of the physicalquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setPHYSICALQUANTITY(QUANTITY value) {
        this.physicalquantity = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the manufacturerpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Sets the value of the manufacturerpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the issuedto property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getISSUEDTO() {
        return issuedto;
    }

    /**
     * Sets the value of the issuedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setISSUEDTO(EQUIPMENTID_Type value) {
        this.issuedto = value;
    }

    /**
     * Gets the value of the returnfrom property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getRETURNFROM() {
        return returnfrom;
    }

    /**
     * Sets the value of the returnfrom property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setRETURNFROM(EQUIPMENTID_Type value) {
        this.returnfrom = value;
    }

    /**
     * Gets the value of the attachtoequipment property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getATTACHTOEQUIPMENT() {
        return attachtoequipment;
    }

    /**
     * Sets the value of the attachtoequipment property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setATTACHTOEQUIPMENT(EQUIPMENTID_Type value) {
        this.attachtoequipment = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the inventorynotes property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINVENTORYNOTES() {
        return inventorynotes;
    }

    /**
     * Sets the value of the inventorynotes property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINVENTORYNOTES(String value) {
        this.inventorynotes = value;
    }

    /**
     * Gets the value of the tobin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Sets the value of the tobin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Gets the value of the inventoryaction property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public USERDEFINEDCODEID_Type getINVENTORYACTION() {
        return inventoryaction;
    }

    /**
     * Sets the value of the inventoryaction property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDCODEID_Type }
     *     
     */
    public void setINVENTORYACTION(USERDEFINEDCODEID_Type value) {
        this.inventoryaction = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
